<?xml version="1.0"?>
<xsl:transform xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
               xmlns:xlf="urn:oasis:names:tc:xliff:document:2.0"
               xmlns:xmrk="xmarker:skl" version="2.0">
  <xsl:output method="xml" indent="yes" encoding="utf-8" />
  <xsl:strip-space elements="*" />
  <xsl:template match="node()|@*">
    <xsl:copy>
      <xsl:apply-templates select="@*|node()" />
    </xsl:copy>
  </xsl:template>

  <xsl:template match="node()|@*" mode="skl">
    <xsl:copy>
      <xsl:apply-templates select="@*|node()" mode="skl" />
    </xsl:copy>
  </xsl:template>

  <xsl:template match="xlf:skeleton" priority="3">
    <xsl:variable name="myname">
      <xsl:for-each select="ancestor::*[local-name()='file']">
        <xsl:value-of select="@original" />
      </xsl:for-each>
    </xsl:variable>
    <xsl:choose>
      <xsl:when test="not($myname='index.html')">
        <xsl:result-document href="{concat('es-',$myname)}">
          <xsl:apply-templates mode="skl" />
        </xsl:result-document>
      </xsl:when>
      <xsl:otherwise>
        <html id="{$myname}">
          <xsl:apply-templates mode="skl" />
        </html>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="xlf:xliff|xlf:file" priority="3">
    <xsl:apply-templates />
  </xsl:template>
  
  <xsl:template match="*[ancestor::xlf:skeleton]" priority="2" mode="skl">
    <xsl:variable name="idref" select="@idref" />
    <xsl:variable name="file">
      <xsl:for-each select="ancestor::xlf:file">
        <xsl:value-of select="count(preceding-sibling::*)" />
      </xsl:for-each>
    </xsl:variable>
    <xsl:element name="{local-name()}">
      <xsl:for-each
       select="@*[not(local-name()='href')and not(local-name()='idref')]">
        <xsl:copy />
      </xsl:for-each>
      <xsl:for-each select="@href">
        <xsl:attribute name="href">
          <xsl:value-of select="concat('es-',.)" />
        </xsl:attribute>
      </xsl:for-each>
      <xsl:choose>
        <xsl:when test="* and not(text())">
          <xsl:apply-templates mode="skl" />
        </xsl:when>
        <xsl:when test="* and text()">
          <xsl:for-each select="ancestor::xlf:file">
            <xsl:apply-templates
                select=".//xlf:unit[@id=$idref]/xlf:segment/xlf:target"
                mode="skl" />
          </xsl:for-each>
        </xsl:when>
        <xsl:when test="text()">
          <xsl:for-each select="ancestor::xlf:file">
            <xsl:apply-templates
                select=".//xlf:unit[@id=$idref]/xlf:segment/xlf:target"
                mode="skl" />
          </xsl:for-each>
        </xsl:when>
        <xsl:otherwise>
          <xsl:apply-templates mode="skl" />
        </xsl:otherwise>
      </xsl:choose>
    </xsl:element>
  </xsl:template>
  <xsl:template match="xlf:target" priority="3" mode="skl">
    <xsl:apply-templates mode="skl" />
  </xsl:template>
  <xsl:template match="xsl:mrk" priority="3" mode="skl">
    <xsl:variable name="myid" select="@id" />
    <xsl:variable name="myname">
      <xsl:for-each select="ancestor::xlf:file//*[@idref=$myid]">
        <xsl:value-of select="local-name()" />
      </xsl:for-each>
    </xsl:variable>
    <xsl:element name="{$myname}">
      <xsl:apply-templates mode="skl" />
    </xsl:element>
  </xsl:template>
</xsl:transform>
