<?xml version="1.0"?>
<xsl:transform xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
               xmlns:xmrk="xmarker:skl" version="2.0">
  <xsl:output method="xml" indent="yes" encoding="utf-8" />
  
  <xsl:strip-space elements="*" />
  
  <xsl:template match="node()|@*">
    <xsl:copy>
      <xsl:apply-templates select="@*|node()" />
    </xsl:copy>
  </xsl:template>
  
  <xsl:template match="node()|@*" mode="body">
    <xsl:copy>
      <xsl:apply-templates select="@*|node()" mode="body" />
    </xsl:copy>
  </xsl:template>
  
  <xsl:template match="node()|@*" mode="head">
    <xsl:copy>
      <xsl:apply-templates select="@*|node()" mode="head" />
    </xsl:copy>
  </xsl:template>
  
  <xsl:template match="html">
    <xliff version="2.0" srcLang="en" trgLang="es"
           xmlns="urn:oasis:names:tc:xliff:document:2.0"
           xmlns:xmrk="urn.xmarker.com">
      <file id="{generate-id()}" original="index.html">
        <skeleton>
          <xsl:apply-templates mode="head">
            <xsl:with-param name="myid" select="generate-id()" />
          </xsl:apply-templates>
        </skeleton>
        <xsl:apply-templates mode="body"></xsl:apply-templates>
      </file>
      <xsl:for-each select="//*[@href]">
        <xsl:variable name="file" select="@href" />
        <file original="{@href}" id="{generate-id()}">
          <skeleton>
            <xsl:apply-templates select="document($file)" mode="head"/>
          </skeleton>
          <xsl:apply-templates select="document($file)" mode="body"/>
        </file>
      </xsl:for-each>
    </xliff>
  </xsl:template>
  
  <xsl:template match="*" mode="head" priority="3">
    <xsl:variable name="myname" select="concat('xmrk:',local-name())" />
    <xsl:element name="{$myname}">
      <xsl:for-each select="@*">
        <xsl:copy />
      </xsl:for-each>
      <xsl:attribute name="idref">
        <xsl:value-of
         select="concat('d',count(preceding::*),count(ancestor::*))" />
      </xsl:attribute>
      <xsl:apply-templates mode="head" />
    </xsl:element>
  </xsl:template>

 
  <xsl:template match="text()" mode="head" priority="4">
    <xsl:text>xxxxxx</xsl:text>
  </xsl:template>
  
  <xsl:template match="*" mode="body" priority="3">
    <xsl:choose>
      <xsl:when test="text() and (preceding-sibling::text())">
        <xsl:variable name="myname"
                      select="concat('xmrk:',local-name())" />
        <pc>
          <xsl:attribute name="id">
            <xsl:value-of
             select="concat('d',count(preceding::*),count(ancestor::*))" />
          </xsl:attribute>
          <xsl:apply-templates mode="body" />
        </pc>
      </xsl:when>
      <xsl:when test="text()">
        <xsl:variable name="myname"
                      select="concat('xmrk:',local-name())" />
        <unit id="{generate-id()}" name="{concat($myname,generate-id())}"
              xmlns="urn:oasis:names:tc:xliff:document:2.0">
          <xsl:attribute name="id">
            <xsl:value-of
             select="concat('d',count(preceding::*),count(ancestor::*))"/>
          </xsl:attribute>
          <segment>
            <source>
              <xsl:apply-templates mode="body" />
            </source>
            <target>
              <xsl:apply-templates mode="body" />
            </target>
          </segment>
        </unit>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates mode="body" />
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
</xsl:transform>